@@ -9,6 +9,8 @@ from oerplib import error
 from oerplib.service.osv import browse
 
 def is_int(value):
+    if isinstance(value, bool):
+        return False
     try:
         int(value)
         return True
@@ -87,10 +89,10 @@ class SelectionField(BaseField):
     def check_value(self, value):
         super(SelectionField, self).check_value(value)
         selection = [val[0] for val in self.selection]
-        if value not in selection:
+        if value and value not in selection:
             raise ValueError(
-                u"The value '{value}' supplied doesn't match with the possible \
-values '{selection}' for the '{field_name}' field".format(
+                u"The value '{value}' supplied doesn't match with the possible "
+                u"values '{selection}' for the '{field_name}' field".format(
                     value=value,
                     selection=selection,
                     field_name=self.name,
@@ -132,22 +134,26 @@ class Many2OneField(BaseField):
                     self.relation,
                     getattr(instance, "_{0}".format(self.name))[0]
                 )
+        return False
 
     def __set__(self, instance, value):
         if isinstance(value, browse.BrowseRecord):
             o_rel = value
         elif is_int(value):
             o_rel = instance.__class__.__oerp__.browse(self.relation, value)
+        elif value in [None, False]:
+            o_rel = False
         else:
-            raise ValueError(u"Value supplied has to be an integer or"
-                             " a browse_record object.")
+            raise ValueError(u"Value supplied has to be an integer, "
+                             u"a browse_record object or False.")
         o_rel = self.check_value(o_rel)
-        setattr(instance, "_{0}".format(self.name), [o_rel.id, o_rel.name])
+        setattr(instance, "_{0}".format(self.name), o_rel and [o_rel.id, False])
+        #setattr(instance, "_{0}".format(self.name), o_rel and o_rel.id)
         instance.__data__['fields_updated'].append(self.name)
 
     def check_value(self, value):
         super(Many2OneField, self).check_value(value)
-        if value.__osv__['name'] != self.relation:
+        if value and value.__osv__['name'] != self.relation:
             raise ValueError(
                 (u"Instance of '{osv_name}' supplied doesn't match with the " +\
                 u"relation '{relation}' of the '{field_name}' field.").format(
